==> aws-sdk-cpp-ec2-1.11.710-1-x86_64.pkg.tar.zst: usr/include/aws/ec2/model/SearchTransitGatewayRoutesResponse.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/core/utils/memory/stl/AWSVector.h>
#include <aws/ec2/EC2_EXPORTS.h>
#include <aws/ec2/model/ResponseMetadata.h>
#include <aws/ec2/model/TransitGatewayRoute.h>

#include <utility>

namespace Aws {
template <typename RESULT_TYPE>
class AmazonWebServiceResult;

namespace Utils {
namespace Xml {
class XmlDocument;
}  // namespace Xml
}  // namespace Utils
namespace EC2 {
namespace Model {
class SearchTransitGatewayRoutesResponse {
 public:
  AWS_EC2_API SearchTransitGatewayRoutesResponse() = default;
  AWS_EC2_API SearchTransitGatewayRoutesResponse(const Aws::AmazonWebServiceResult<Aws::Utils::Xml::XmlDocument>& result);
  AWS_EC2_API SearchTransitGatewayRoutesResponse& operator=(const Aws::AmazonWebServiceResult<Aws::Utils::Xml::XmlDocument>& result);

  ///@{
  /**
   * <p>Information about the routes.</p>
   */
  inline const Aws::Vector<TransitGatewayRoute>& GetRoutes() const { return m_routes; }
  template <typename RoutesT = Aws::Vector<TransitGatewayRoute>>
  void SetRoutes(RoutesT&& value) {
    m_routesHasBeenSet = true;
    m_routes = std::forward<RoutesT>(value);
  }
  template <typename RoutesT = Aws::Vector<TransitGatewayRoute>>
  SearchTransitGatewayRoutesResponse& WithRoutes(RoutesT&& value) {
    SetRoutes(std::forward<RoutesT>(value));
    return *this;
  }
  template <typename RoutesT = TransitGatewayRoute>
  SearchTransitGatewayRoutesResponse& AddRoutes(RoutesT&& value) {
    m_routesHasBeenSet = true;
    m_routes.emplace_back(std::forward<RoutesT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>Indicates whether there are additional routes available.</p>
   */
  inline bool GetAdditionalRoutesAvailable() const { return m_additionalRoutesAvailable; }
  inline void SetAdditionalRoutesAvailable(bool value) {
    m_additionalRoutesAvailableHasBeenSet = true;
    m_additionalRoutesAvailable = value;
  }
  inline SearchTransitGatewayRoutesResponse& WithAdditionalRoutesAvailable(bool value) {
    SetAdditionalRoutesAvailable(value);
    return *this;
  }
  ///@}

  ///@{

  inline const ResponseMetadata& GetResponseMetadata() const { return m_responseMetadata; }
  template <typename ResponseMetadataT = ResponseMetadata>
  void SetResponseMetadata(ResponseMetadataT&& value) {
    m_responseMetadataHasBeenSet = true;
    m_responseMetadata = std::forward<ResponseMetadataT>(value);
  }
  template <typename ResponseMetadataT = ResponseMetadata>
  SearchTransitGatewayRoutesResponse& WithResponseMetadata(ResponseMetadataT&& value) {
    SetResponseMetadata(std::forward<ResponseMetadataT>(value));
    return *this;
  }
  ///@}
 private:
  Aws::Vector<TransitGatewayRoute> m_routes;

  bool m_additionalRoutesAvailable{false};

  ResponseMetadata m_responseMetadata;
  bool m_routesHasBeenSet = false;
  bool m_additionalRoutesAvailableHasBeenSet = false;
  bool m_responseMetadataHasBeenSet = false;
};

}  // namespace Model
}  // namespace EC2
}  // namespace Aws

==> aws-sdk-cpp-ec2-1.11.749-1-x86_64.pkg.tar.zst: usr/include/aws/ec2/model/SearchTransitGatewayRoutesResponse.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/core/utils/memory/stl/AWSVector.h>
#include <aws/ec2/EC2_EXPORTS.h>
#include <aws/ec2/model/ResponseMetadata.h>
#include <aws/ec2/model/TransitGatewayRoute.h>

#include <utility>

namespace Aws {
template <typename RESULT_TYPE>
class AmazonWebServiceResult;

namespace Utils {
namespace Xml {
class XmlDocument;
}  // namespace Xml
}  // namespace Utils
namespace EC2 {
namespace Model {
class SearchTransitGatewayRoutesResponse {
 public:
  AWS_EC2_API SearchTransitGatewayRoutesResponse() = default;
  AWS_EC2_API SearchTransitGatewayRoutesResponse(const Aws::AmazonWebServiceResult<Aws::Utils::Xml::XmlDocument>& result);
  AWS_EC2_API SearchTransitGatewayRoutesResponse& operator=(const Aws::AmazonWebServiceResult<Aws::Utils::Xml::XmlDocument>& result);

  ///@{
  /**
   * <p>Information about the routes.</p>
   */
  inline const Aws::Vector<TransitGatewayRoute>& GetRoutes() const { return m_routes; }
  template <typename RoutesT = Aws::Vector<TransitGatewayRoute>>
  void SetRoutes(RoutesT&& value) {
    m_routesHasBeenSet = true;
    m_routes = std::forward<RoutesT>(value);
  }
  template <typename RoutesT = Aws::Vector<TransitGatewayRoute>>
  SearchTransitGatewayRoutesResponse& WithRoutes(RoutesT&& value) {
    SetRoutes(std::forward<RoutesT>(value));
    return *this;
  }
  template <typename RoutesT = TransitGatewayRoute>
  SearchTransitGatewayRoutesResponse& AddRoutes(RoutesT&& value) {
    m_routesHasBeenSet = true;
    m_routes.emplace_back(std::forward<RoutesT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>Indicates whether there are additional routes available.</p>
   */
  inline bool GetAdditionalRoutesAvailable() const { return m_additionalRoutesAvailable; }
  inline void SetAdditionalRoutesAvailable(bool value) {
    m_additionalRoutesAvailableHasBeenSet = true;
    m_additionalRoutesAvailable = value;
  }
  inline SearchTransitGatewayRoutesResponse& WithAdditionalRoutesAvailable(bool value) {
    SetAdditionalRoutesAvailable(value);
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The token to use to retrieve the next page of results. This value is
   * <code>null</code> when there are no more results to return.</p>
   */
  inline const Aws::String& GetNextToken() const { return m_nextToken; }
  template <typename NextTokenT = Aws::String>
  void SetNextToken(NextTokenT&& value) {
    m_nextTokenHasBeenSet = true;
    m_nextToken = std::forward<NextTokenT>(value);
  }
  template <typename NextTokenT = Aws::String>
  SearchTransitGatewayRoutesResponse& WithNextToken(NextTokenT&& value) {
    SetNextToken(std::forward<NextTokenT>(value));
    return *this;
  }
  ///@}

  ///@{

  inline const ResponseMetadata& GetResponseMetadata() const { return m_responseMetadata; }
  template <typename ResponseMetadataT = ResponseMetadata>
  void SetResponseMetadata(ResponseMetadataT&& value) {
    m_responseMetadataHasBeenSet = true;
    m_responseMetadata = std::forward<ResponseMetadataT>(value);
  }
  template <typename ResponseMetadataT = ResponseMetadata>
  SearchTransitGatewayRoutesResponse& WithResponseMetadata(ResponseMetadataT&& value) {
    SetResponseMetadata(std::forward<ResponseMetadataT>(value));
    return *this;
  }
  ///@}
 private:
  Aws::Vector<TransitGatewayRoute> m_routes;

  bool m_additionalRoutesAvailable{false};

  Aws::String m_nextToken;

  ResponseMetadata m_responseMetadata;
  bool m_routesHasBeenSet = false;
  bool m_additionalRoutesAvailableHasBeenSet = false;
  bool m_nextTokenHasBeenSet = false;
  bool m_responseMetadataHasBeenSet = false;
};

}  // namespace Model
}  // namespace EC2
}  // namespace Aws
